pub enum VerifyCommandError {
UnknownPayloadType(String),
Signature(VerifyError),
PayloadParse(String),
}Variants
UnknownPayloadType(String)
payloadType on the envelope is not a known command type.
Signature(VerifyError)
Signature verification against the authorized key set failed.
PayloadParse(String)
Payload bytes did not deserialize into the expected struct.