pub enum VerifyError {
PayloadDecode(String),
UnknownKey(String),
InvalidSignature(String),
NoValidSignature,
MalformedSignature(String),
}Expand description
Error from verification.
Variants
PayloadDecode(String)
The payload could not be base64-decoded.
UnknownKey(String)
A key ID in the envelope has no corresponding trusted public key.
InvalidSignature(String)
A signature was cryptographically invalid.
NoValidSignature
No valid signature was found from any trusted key (VerifyAny only).
MalformedSignature(String)
The signature bytes were malformed (wrong length etc.).