export

Function export 

pub fn export(
    bundle_id: &str,
    out_path: &Path,
    storage: &Store,
) -> Result<(), BundleError>
Export a bundle to a .treeship file.

The export file contains the bundle envelope and all referenced artifact envelopes. This is the portable format for sharing proof chains.