schema_json

Function schema_json 

pub fn schema_json(suffix: &str) -> Option<&'static str>
Returns the raw JSON Schema text for a registered predicate suffix, if any. This is the canonical published schema for the predicate.